==> rocketmq-all-5.1.1-source-release.zip: rocketmq-all-5.1.1-source-release/tieredstore/src/main/java/org/apache/rocketmq/tieredstore/common/MessageCacheKey.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.rocketmq.tieredstore.common;

import java.util.Objects;
import org.apache.rocketmq.tieredstore.container.TieredMessageQueueContainer;

public class MessageCacheKey {
    private TieredMessageQueueContainer container;
    private long offset;

    public MessageCacheKey(TieredMessageQueueContainer container, long offset) {
        this.container = container;
        this.offset = offset;
    }

    public TieredMessageQueueContainer getContainer() {
        return container;
    }

    public long getOffset() {
        return offset;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        MessageCacheKey that = (MessageCacheKey) o;
        return offset == that.offset && Objects.equals(container, that.container);
    }

    @Override
    public int hashCode() {
        return Objects.hash(container, offset);
    }
}

==> rocketmq-all-5.1.2-source-release.zip: rocketmq-all-5.1.2-source-release/tieredstore/src/main/java/org/apache/rocketmq/tieredstore/common/MessageCacheKey.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.rocketmq.tieredstore.common;

import java.util.Objects;
import org.apache.rocketmq.tieredstore.file.CompositeFlatFile;

public class MessageCacheKey {

    private final CompositeFlatFile flatFile;
    private final long offset;

    public MessageCacheKey(CompositeFlatFile flatFile, long offset) {
        this.flatFile = flatFile;
        this.offset = offset;
    }

    public CompositeFlatFile getFlatFile() {
        return flatFile;
    }

    public long getOffset() {
        return offset;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        MessageCacheKey that = (MessageCacheKey) o;
        return offset == that.offset && Objects.equals(flatFile, that.flatFile);
    }

    @Override
    public int hashCode() {
        return Objects.hash(flatFile, offset);
    }
}
